==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>Standaardinstellingen voor nieuwe tekeningen</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Dimensie instellingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Bemating</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scientific</source>
        <translation>Wetenschappelijk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Decimaal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Technisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Bouwkunde</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Breuken</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Decimale Graden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Deg/min/sec</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Graden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radialen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Te meten eenheid</translation>
    </message>
    <message>
        <location line="+198"/>
        <source>Unit / Format</source>
        <translation>Eenheid / Formaat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>De tekening eenheid moet &apos;Inch&apos; of &apos;Foot&apos; zijn dat bematingen in het format &apos;Architectuur&apos; of &apos;Technisch&apos; kunnen worden weergegeven. Format teruggezet op &apos;Decimaal&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Maten</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Houd verhoudingen</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Teksthoogte:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Hulplijn afzet:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Hulplijn extentie:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Maat lijn uitsparing:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Pijl grootte:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Groote schaal factor:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Pijl stijl</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Pijl</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Bouwkunde Tick</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Lettertype</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Bematingtekst lettertype:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translation>Tekstformaat</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Liniaire bemating</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Formaat:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>P&amp;recisie:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Toon afsluitende nullen</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Hoek bemating</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>F&amp;ormaat:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>Pre&amp;cisie:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Voorbeeld</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>Standaardinstellingen voor nieuwe tekeningen</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Dimensie instellingen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Bemating</translation>
    </message>
    <message>
        <location line="+108"/>
        <source>point</source>
        <translation>Punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>comma</source>
        <translation>Komma</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>space</source>
        <translation>Spatie</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Scientific</source>
        <translation>Wetenschappelijk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Decimaal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Technisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Bouwkunde</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Breuken</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Decimale Graden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Deg/min/sec</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Graden</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radialen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Te meten eenheid</translation>
    </message>
    <message>
        <location line="+209"/>
        <source>Unit / Format</source>
        <translation>Eenheid / Formaat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>De tekening eenheid moet &apos;Inch&apos; zijn dat bematingen in het format &apos;Architectuur&apos; of &apos;Technisch&apos; kunnen worden weergegeven. Format teruggezet op &apos;Decimaal&apos;.</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">De tekening eenheid moet &apos;Inch&apos; of &apos;Foot&apos; zijn dat bematingen in het format &apos;Architectuur&apos; of &apos;Technisch&apos; kunnen worden weergegeven. Format teruggezet op &apos;Decimaal&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Maten</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Houd verhoudingen</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Teksthoogte:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Hulplijn afzet:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Hulplijn extentie:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Maat lijn uitsparing:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Pijl grootte:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Groote schaal factor:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Pijl stijl</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Pijl</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Bouwkunde Tick</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Lettertype</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Bematingtekst lettertype:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Number Format</source>
        <translation>Nummer formaat</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Decimal separator:</source>
        <translation>Decimaalscheidingsteken:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Label Format</source>
        <translation>Tekstformaat</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Liniaire bemating</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Formaat:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>P&amp;recisie:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Toon afsluitende nullen</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Hoek bemating</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>F&amp;ormaat:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>Pre&amp;cisie:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Voorbeeld</translation>
    </message>
</context>
</TS>
